import { savePosts, getPostsDetail, updatePosts } from "@/services/posts";
import { getStoreList } from "@/services/stock";
import {
  PageContainer,
  ProForm,
  ProFormSelect,
  ProFormText,
} from "@ant-design/pro-components";
import { useNavigate, useSearchParams } from "react-router-dom";
import { Card, Col, message, Row, Space } from "antd";
import { useEffect, useRef, useState } from "react";
import UploadFile from "@/components/UploadFile";
import Wangeditor from "@/components/Wangeditor";

export default (props) => {
  const [searchParams] = useSearchParams();
  const id = searchParams.get("id");
  // const [foodDict, setFoodDict] = useState([]);
  const navigate = useNavigate();

  const formRef = useRef();

  useEffect(() => {
    if (id) {
      getPostsDetail(id).then((res) => {
        formRef.current.setFieldsValue({
          ...res,
          filesList: res.filesList?.map((x) => x.fileAddr)[0]||null,
        });
      });
    }
  }, [id]);

  const onFinish = async (values) => {
    savePosts({
      ...values,
      type: 'emergency-plan',
      filesList: values.filesList
        ? [
            {
              fileAddr: values.filesList,
              fileName: values.filesList?.substring(
                values.filesList?.lastIndexOf("/") + 1
              ),
            },
          ]
        : null,
      status: Number(values.status),
      ...(id?{id}:{}),
    }).then((res) => {
      navigate(-1);
    });
    // }

    return false;
  };

  return (
    <PageContainer>
      <Card>
        <ProForm
          formRef={formRef}
          layout={"horizontal"}
          labelCol={{ span: 8 }}
          wrapperCol={{ span: 12 }}
          onFinish={onFinish}
          initialValues={{ status: 0 }}
          submitter={{
            searchConfig: {
              resetText: "返回",
            },
            onReset: () => navigate(-1),
            render: (props, doms) => {
              return (
                <Row>
                  <Col span={8} offset={8}>
                    <Space>{doms}</Space>
                  </Col>
                </Row>
              );
            },
          }}
        >
          <ProFormText
            name="title"
            label="内容名称"
            placeholder="请输入内容名称"
            rules={[{ required: true, message: "请输入内容名称" }]}
            width={460}
          />

          <ProForm.Item
            name="detail"
            label="发布详情"
            placeholder="请输入发布详情"
            rules={[{ required: true, message: "请输入发布详情" }]}
          >
            <Wangeditor></Wangeditor>
          </ProForm.Item>
          <ProForm.Item name="filesList" label="文件">
            <UploadFile preview={true}></UploadFile>
          </ProForm.Item>

          <ProFormSelect
            name="status"
            label="状态"
            placeholder="请选择"
            rules={[{ required: true, message: "请选择状态" }]}
            width={460}
            options={[
              {
                value: 0,
                label: "未发布",
              },
              {
                value: 1,
                label: "已发布",
              },
            ]}
          />
          <ProFormText
            name="createPerson"
            label="发布人"
            placeholder="请输入发布人"
            width={460}
          />
        </ProForm>
      </Card>
    </PageContainer>
  );
};
