import React from 'react';
import { Row, Col } from 'antd';
import classNames from 'classnames';
import { getSummary } from '@/services/statis';
import icon1 from '@/assets/images/statistic/数字统计.png';
import icon2 from '@/assets/images/statistic/接待军人总数.png';
import icon3 from '@/assets/images/statistic/保障机构数.png';
import icon4 from '@/assets/images/statistic/设备数量.png';
import Styles from './style.module.less';

const DataCard = (props) => {
  const { className, icon, title, value = 0, size } = props;

  const cls = classNames(Styles['data-card'], className);

  const valStyle = React.useMemo(() => {
    return size ? { fontSize: size } : {}
  }, [size]);

  return (
    <dl className={cls}>
      <dt style={valStyle}>{value}</dt>
      <dd>{title}</dd>
      <img src={icon} alt="" />
    </dl>
  )
}

export default (props) => {
  
  const [data, setData] = React.useState({});

  React.useEffect(() => {
    getSummary().then(setData);
  }, []);

  return (
    <Row gutter={props.gutter} justify="space-between">
      <Col span={6}>
        <DataCard title="任务总数" value={data.taskCount} icon={icon1} className={Styles['bk1']} />
      </Col>
      <Col span={6}>
        <DataCard title="接待军人总数" value={data.personNum} icon={icon2} className={Styles['bk2']} />
      </Col>
      <Col span={6}>
        <DataCard title="总体评价" value={data.evaValue} icon={icon3} className={Styles['bk3']} size="24px" />
      </Col>
      <Col span={6}>
        <DataCard title="设备数量" value={data.deviceNum} icon={icon4} className={Styles['bk4']} />
      </Col>
    </Row>
  )
}
